@@ -1,5 +1,4 @@
 from __future__ import absolute_import, print_function
-from distutils.spawn import find_executable
 import os
 import logging
 
@@ -19,6 +18,11 @@ except ImportError:
     # methods
     mozilla_aws_cli_config = None
 
+try:
+    from shutil import which
+except ImportError:
+    from whichcraft import which
+
 if sys.version_info[0] >= 3:
     import configparser
     basestring = str
@@ -56,7 +60,7 @@ def validate_output(ctx, param, value):
     del ctx, param  # we don't use these arguments
     if value is None:
         pass
-    elif value.lower() == "awscli" and not find_executable("aws"):
+    elif value.lower() == "awscli" and which("aws") is None:
         raise click.BadParameter("AWS CLI is not detected on local system.")
 
     return value
