@@ -4,10 +4,11 @@ import json
 import logging
 import os
 import sys
-import time
 import traceback
 import webbrowser
 
+from future.moves.urllib.parse import urlparse, urlencode, urlunparse
+
 import requests
 
 from . import sts_conn
@@ -24,20 +25,12 @@ from .role_picker import (
 )
 from .utils import (
     base64_without_padding,
-    exit_sigint,
     generate_challenge,
-    role_arn_to_profile_name,
+    get_alias,
+    role_arn_to_display_name,
     STSWarning
 )
 
-try:
-    # P3
-    from urllib.parse import urlencode, urlunparse, urlparse
-except ImportError:
-    # P2 Compat
-    from urllib import urlencode
-    from urlparse import urlunparse, urlparse
-
 
 logger = logging.getLogger(__name__)
 ENV_VARIABLE_NAME_MAP = {
@@ -86,7 +79,7 @@ class Login:
         self.output = self.config.get("output", "envvar")
         self.print_role_arn = self.config.get("print_role_arn", True)
         self.redirect_uri = None
-        self.role = None
+        self.display_name = None
         self.role_arn = role_arn
         self.role_map = None
 
@@ -411,10 +404,14 @@ class Login:
     def print_output(self):
         # TODO: Create a global config object?
         if self.credentials is not None:
-            if self.profile_name is None:
-                self.profile_name = role_arn_to_profile_name(
-                    self.role_arn, self.role_map)
             output_map = {}
+
+            # get a role name (for the command line), and use it for the profile
+            # name if it wasn't manually overridden
+            self.display_name = role_arn_to_display_name(self.role_arn, self.role_map)
+            if self.profile_name is None:
+                self.profile_name = self.display_name
+
             if self.output == "envvar":
                 output_map.update(
                     {ENV_VARIABLE_NAME_MAP[x]: self.credentials[x]
@@ -423,7 +420,7 @@ class Login:
                 output_map.update({
                     "AWS_PROFILE": None,
                     "AWS_SHARED_CREDENTIALS_FILE": None,
-                    "MAWS_PROMPT": self.profile_name})
+                    "MAWS_PROMPT": self.display_name})
             elif self.output == "shared":
                 # Write the credentials
                 path = write_aws_shared_credentials(
@@ -433,37 +430,39 @@ class Login:
                     output_map.update({
                         "AWS_PROFILE": self.profile_name,
                         "AWS_SHARED_CREDENTIALS_FILE": path,
-                        "MAWS_PROMPT": self.profile_name})
+                        "MAWS_PROMPT": self.display_name})
                     output_map.update({
                         x: None for x in ENV_VARIABLE_NAME_MAP.values()})
             elif self.output == "awscli":
                 # Call into aws a bunch of times
                 if write_aws_cli_credentials(self.profile_name,
                                              self.credentials):
-                    if self.profile_name != "default":
-                        output_map.update({
-                            "AWS_PROFILE": self.profile_name,
-                            "AWS_SHARED_CREDENTIALS_FILE": None,
-                            "MAWS_PROMPT": self.profile_name
-                        })
-                        output_map.update({
-                            x: None for x in ENV_VARIABLE_NAME_MAP.values()})
+                    output_map.update({
+                        "AWS_PROFILE": self.profile_name,
+                        "AWS_SHARED_CREDENTIALS_FILE": None,
+                        "MAWS_PROMPT": self.display_name})
+                    output_map.update({
+                        x: None for x in ENV_VARIABLE_NAME_MAP.values()})
                 else:
                     logger.error("Unable to write credentials with aws-cli.")
             elif self.output == "boto":
                 # this output can be used directly by boto3
-                print(json.dumps({
+                print(json.dumps(
+                    {
                         "aws_access_key_id": self.credentials["AccessKeyId"],
                         "aws_secret_access_key": self.credentials["SecretAccessKey"],
-                        "aws_session_token": self.credentials["SessionToken"]},
+                        "aws_session_token": self.credentials["SessionToken"]
+                    },
                     indent=2))
                 self.print_output_map = False
             elif self.output == "js":
                 # this output can be used directly by the AWS Javascript SDK
-                print(json.dumps({
+                print(json.dumps(
+                    {
                         "accessKeyId": self.credentials["AccessKeyId"],
                         "secretAccessKey": self.credentials["SecretAccessKey"],
-                        "sessionToken": self.credentials["SessionToken"]},
+                        "sessionToken": self.credentials["SessionToken"]
+                    },
                     indent=2))
                 self.print_output_map = False
             else:
@@ -509,8 +508,7 @@ class Login:
             return None
 
         account_id = self.role_arn.split(":")[4]
-        account_alias = self.role_map.get("aliases", {}).get(
-            account_id, [account_id])[0]
+        account_alias = get_alias(self.role_map, account_id)
         role = self.role_arn.split(":")[5].split("/")[-1]
         issuer_url_query = urlencode({"account": account_alias, "role": role})
         issuer_url = urlunparse(
