@@ -30,7 +30,23 @@ def generate_challenge(code_verifier):
         hashlib.sha256(code_verifier.encode()).digest())
 
 
-def role_arn_to_profile_name(role_arn, role_map):
+def get_alias(role_map, account_id):
+    """Given a role map and account ID return an account alias
+
+    :param role_map: A dictionary containing an 'aliases' key with a map of
+                     account IDs to lists of aliases
+    :param account_id: The AWS account ID number
+    :return: An AWS account alias if it exists or the account ID if not
+    """
+    if ('aliases' in role_map
+            and account_id in role_map['aliases']
+            and len(role_map['aliases'][account_id]) > 0):
+        return role_map['aliases'][account_id][0]
+    else:
+        return account_id
+
+
+def role_arn_to_display_name(role_arn, role_map):
     if not role_map:
         role_map = {}
 
@@ -41,10 +57,10 @@ def role_arn_to_profile_name(role_arn, role_map):
 
     # Get the AWS account id from the role ARN, and then see if it's in the map
     account_id = role_arn.split(":")[4]
-    account_id = role_map.get("aliases", {}).get(account_id, [account_id])[0]
+    alias = get_alias(role_map, account_id)
 
     # such as infosec-somerole
-    return "-".join([account_id, role])
+    return "-".join([alias, role])
 
 
 def strip_xmlns(tag):
